==> VGAMextra_0.0-1.tar.gz: VGAMextra/man/notDocumentedYetVGAMextra.Rd <==
\name{notDocumentedYetVGAMextra}
\alias{notDocumentedYetVGAMextra}
%
% Utilities and/or diagnostics
\alias{ARpEIM.G2}
\alias{MAqEIM.G2}
\alias{ARMA.EIM.G2}
\alias{rINGARCH}
\alias{combVGAMextra}
\alias{arwzTS}
\alias{PIT}
\alias{typeTS}
%\alias{PIT.vglm}
\alias{responseVGAMex}
%\alias{responseVGAMex.vglm}
\alias{execute.PIT}
%\alias{response.vgltsm}

% INFORMATIVE
\alias{ .onAttach }
\alias{vgamextraNEWS}

%% Re. Multinormal, 2018-02-13
%\alias{MVNcov}
\alias{trinormal}
%\alias{dmultinorm}

%% KPSS test
%\alias{KPSS.test}
\alias{con.est.s2l}
\alias{pVal.KPSS.test}

%
% TIME SERIES ff
%\alias{ARXff}
%\alias{MAXff}
%\alias{ARMAXff}
%\alias{ARIMAXff}
\alias{poissonTSff}
\alias{ARMAX.GARCHff}
\alias{NegBinomTSff}
\alias{VGLM.INGARCHff}
%\alias{ARMA.studentt.ff}
%\alias{ARIMAX.errors.ff}
%\alias{binomialTSff}
\alias{yulesimonTSff}
\alias{logarithmicTSff}
\alias{dARp}
\alias{dMAq}
\alias{dARMA}
\alias{AR1extra}
\alias{rAR.GARCH}
\alias{AR1EIM.G2}
\alias{dAR1extra}
\alias{VARff.control}
\alias{ARXff.control}
\alias{MAXff.control}
\alias{MVNcov.control}
\alias{ARMAXff.control}
\alias{ARIMAXff.control}
\alias{trinormal.control}
\alias{poissonTSff.control}
\alias{NegBinomTSff.control}
\alias{yulesimonTSff.control}
\alias{ARMAX.GARCHff.control}
\alias{ECM.EngleGran.control}
\alias{VGLM.INGARCHff.control}
\alias{logarithmicTSff.control}
\alias{ARIMAX.errors.ff.control}
\alias{ARMA.studentt.ff.control}
%\alias{INGARCHff.control}
\alias{quick.check.coeffs}
\alias{interleaveArray.VGAMextra}



%- Also NEED an '\alias' for EACH other topic documented here.
\title{
  Not-documented functions and classes in \pkg{VGAMextra}
}
\description{
  
 Those functions not documented yet in 
  \pkg{VGAMextra} are aliased to this file.
}
%\usage{
%notDocumentedYetVGAMextra(x)
%}
%- maybe also 'usage' for other objects documented here.
%\arguments{
%  \item{x}{
%%     ~~Describe \code{x} here~~
%}
%}
\details{

  These functions are still under review or being tested, and will
  be documented over time.
}
\value{
  Overall, these functions returns objects required by 
  time series family functions in \pkg{VGAMextra}.
  
  Further details will be given shortly.
}
%\references{
%% ~put references to the literature/web site here ~
%}
\author{
  V. Miranda
}
%\note{
%%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}

==> VGAMextra_0.0-2.tar.gz: VGAMextra/man/notDocumentedYetVGAMextra.Rd <==
\name{notDocumentedYetVGAMextra}
\alias{notDocumentedYetVGAMextra}
%
% Utilities and/or diagnostics
\alias{ARpEIM.G2}
\alias{MAqEIM.G2}
\alias{ARMA.EIM.G2}
\alias{rINGARCH}
\alias{combVGAMextra}
\alias{arwzTS}
\alias{PIT}
\alias{typeTS}
%\alias{PIT.vglm}
\alias{responseVGAMex}
%\alias{responseVGAMex.vglm}
\alias{execute.PIT}
%\alias{response.vgltsm}

% Two par. links
\alias{uninormalMod}
\alias{uninormalQlink}


% INFORMATIVE
\alias{ .onAttach }
\alias{vgamextraNEWS}

%% Re. Multinormal, 2018-02-13
%\alias{MVNcov}
%\alias{trinormal}
%\alias{dmultinorm}

%% KPSS test
%\alias{KPSS.test}
\alias{con.est.s2l}
\alias{pVal.KPSS.test}

%
% TIME SERIES ff
%\alias{ARXff}
%\alias{MAXff}
%\alias{ARMAXff}
%\alias{ARIMAXff}
\alias{poissonTSff}
\alias{ARMAX.GARCHff}
\alias{NegBinomTSff}
\alias{VGLM.INGARCHff}
%\alias{ARMA.studentt.ff}
%\alias{ARIMAX.errors.ff}
%\alias{binomialTSff}
\alias{yulesimonTSff}
\alias{logarithmicTSff}
\alias{dARp}
\alias{dMAq}
\alias{dARMA}
%\alias{AR1extra}
\alias{rAR.GARCH}
%\alias{AR1EIM.G2}
%\alias{dAR1extra}
\alias{VARff.control}
\alias{ARXff.control}
\alias{MAXff.control}
\alias{MVNcov.control}
\alias{ARMAXff.control}
\alias{ARIMAXff.control}
\alias{poissonTSff.control}
\alias{NegBinomTSff.control}
\alias{yulesimonTSff.control}
\alias{ARMAX.GARCHff.control}
\alias{ECM.EngleGran.control}
\alias{VGLM.INGARCHff.control}
\alias{trinormalCovff.control}
\alias{logarithmicTSff.control}
\alias{ARIMAX.errors.ff.control}
\alias{ARMA.studentt.ff.control}
%\alias{INGARCHff.control}
\alias{quick.check.coeffs}
\alias{interleaveArray.VGAMextra}



%- Also NEED an '\alias' for EACH other topic documented here.
\title{
  Not-documented functions and classes in \pkg{VGAMextra}
}
\description{
  
 Those functions not documented yet in 
  \pkg{VGAMextra} are aliased to this file.
}
%\usage{
%notDocumentedYetVGAMextra(x)
%}
%- maybe also 'usage' for other objects documented here.
%\arguments{
%  \item{x}{
%%     ~~Describe \code{x} here~~
%}
%}
\details{

  These functions are still under review or being tested, and will
  be documented over time.
}
\value{
  Overall, these functions returns objects required by 
  time series family functions in \pkg{VGAMextra}.
  
  Further details will be given shortly.
}
%\references{
%% ~put references to the literature/web site here ~
%}
\author{
  V. Miranda
}
%\note{
%%%  ~~further notes~~
%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

%\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
%}
